advertools.code\_recipes package
================================

Submodules
----------

.. toctree::
   :maxdepth: 4

   advertools.code_recipes.spider_strategies

Module contents
---------------

.. automodule:: advertools.code_recipes
   :members:
   :undoc-members:
   :show-inheritance:
